==> nextcloud-31.0.11.tgz: nextcloud/apps/circles/l10n/et_EE.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Lõid tiimi {circle}",
    "{author} created the team {circle}" : "{author} lõi tiimi {circle} ",
    "You deleted {circle}" : "Kustutasid {circle}",
    "{author} deleted {circle}" : "{author} kustutas {circle}",
    "You made {member} join {circle}" : "Panid {member} {circle}-ga liituma",
    "{author} made {member} join {circle}" : "{author} pani {member} {circle}-ga liituma",
    "You added team {member} as member to {circle}" : "Lisasid tiimiliikme {member}{circle} liikmeks",
    "{author} added team {member} as member to {circle}" : "{author}lisas tiimiliikme {member} {circle} liikmeks",
    "You made {member} leave {circle}" : "Panid {member} {circle}-st lahkuma",
    "{author} made {member} leave {circle}" : "{author} pani {member} {circle}-st lahkuma",
    "You removed {member} from {circle}" : "Eemaldasid {member} {circle}-st",
    "{author} removed {member} from {circle}" : "{author} eemaldas {member} {circle}-st",
    "You joined {circle}" : "Liitusid {circle}-ga",
    "{member} joined {circle}" : "{member} liitus {circle}-ga",
    "You accepted the invitation to join {circle}" : "Võtsid vastu kutse {circle}-ga liitumiseks ",
    "{member} accepted the invitation to join {circle}" : "{member} võttis vastu kutse {circle}-ga liitumiseks",
    "You added {member} as member to {circle}" : "Lisasid {member} {circle} liikmeks",
    "You have been added as member to {circle} by {author}" : "Sind lisati {circle} liikmeks {author} poolt",
    "{member} has been added as member to {circle} by {author}" : "{member} lisati {circle} liikmeks {author} poolt",
    "You added {external} to {circle}" : "Lisasid {external} {circle}-sse",
    "{external} has been added to {circle} by {author}" : "{external} lisati {circle}-sse {author} poolt",
    "You accepted {member}'s request to join {circle}" : "Aksepteerisid {member} soovi liituda {circle}-ga",
    "Your request to join {circle} has been accepted by {author}" : "Sinu liitumissoov {circle}-ga liitumiseks on {author} poolt heaks kiidetud",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} liitumissoov {circle}-ga liitumiseks on {author} poolt heaks kiidetud",
    "You left {circle}" : "Lahkusid {circle}-st",
    "{member} left {circle}" : "{member} lahkus {circle}-st",
    "You declined the invitation to join {circle}" : "Keeldusid kutsest „{circle}“ tiimiga liitumiseks",
    "{member} declined an invitation to join {circle}" : "{member} keeldus kutsest {circle}-ga liitumiseks",
    "You cancelled your request to join {circle}" : "Tühistasid liitumissoovi „{circle}“ tiimiga",
    "{member} cancelled a request to join {circle}" : "{member} tühistas {circle}-ga liitumise soovi",
    "You have been removed from {circle} by {author}" : "Sind eemaldati {circle}-st {author} poolt",
    "{member} has been removed from {circle} by {author}" : "{member} eemaldati {circle}-st {author} poolt",
    "You removed {external} from {circle}" : "Eemaldasid {external} {circle}-st",
    "{external} has been removed from {circle} by {author}" : "{external} eemaldati {circle}-st {author} poolt",
    "You cancelled {member}'s invitation to join {circle}" : "Tühistasid {member} kutse {circle}-ga liitumiseks",
    "Your invitation to join {circle} has been cancelled by {author}" : "Sinu kutse {circle}-ga liitumiseks tühistati {author} poolt",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} tühistas {member} kutse {circle}-ga liitumiseks",
    "You dismissed {member}'s request to join {circle}" : "Keeldusid {member} soovist liituda {circle}-ga",
    "Your request to join {circle} has been dismissed by {author}" : "Su {circle}-ga liitumise soov lükati tagasi {author} poolt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} soov liituda {circle}-ga lükati {author} poolt tagasi",
    "You invited {member} to join {circle}" : "Kutsusid {member} {circle}-ga liituma",
    "You have been invited to join {circle} by {author}" : "Sind kutsuti {circle}-ga liituma {author} poolt",
    "{member} has been invited to join {circle} by {author}" : "{member} kutsuti {circle}-ga liituma {author} poolt",
    "You changed {member}'s level in {circle} to %1$s" : "Muutsid {member} taseme {circle}-s %1$s-le",
    "{author} changed your level in {circle} to %1$s" : "{author} muutis sinu taset {circle}-s %1$s-le",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} muutis {member} taset {circle}-s %1$s-le",
    "You sent a request to join {circle}" : "Saatsid soovi {circle}-ga liituda",
    "{member} sent a request to join {circle}" : "{member} saatis soovi liituda {circle}-ga",
    "You are the new owner of {circle}" : "Oled {circle} uus omanik",
    "{member} is the new owner of {circle}" : "{member} on {circle} uus omanik",
    "Teams" : "Tiimid",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sündmuste kohta, mis toimuvad <strong>tiimis</strong>, mille liige te olete",
    "Any important event in a <strong>team</strong> you are moderating" : "Iga oluline sündmus <strong>tiimis</strong>, mida modereerite",
    "On global events happening in any <strong>team</strong>" : "Mis tahes <strong>tiimis</strong> toimuvate globaalsete sündmuste kohta",
    "Single" : "Üks",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Visible" : "Nähtav",
    "Open" : "Ava",
    "Invite" : "Kutse",
    "Join request" : "Liitumissoov",
    "Friends" : "Sõbrad",
    "Password protected" : "Kaitstud salasõnaga",
    "No Owner" : "Omanikuta",
    "Hidden" : "Peidetud",
    "Backend" : "Taustateenus",
    "Local" : "Kohalik",
    "Root" : "Juur",
    "Team invite" : "Tiimi kutse",
    "Federated" : "Liitpilves",
    "Mount point" : "Kinnituskoht",
    "Nextcloud Account" : "Nextcloudi kasutajakonto",
    "Nextcloud Group" : "Nextcloudi Grupp",
    "Email address" : "E-posti aadress",
    "Contact" : "Kontakt",
    "Team" : "Tiim",
    "Nextcloud App" : "Nextcloudi rakendus",
    "Teams App" : "Tiimide rakendus",
    "Admin Command Line" : "Haldus käsurealt",
    "Member" : "Liige",
    "Moderator" : "Moderaator",
    "Admin" : "Admin",
    "Owner" : "Omanik",
    "%s shared »%s« with you." : "%s jagas sinuga „%s“ faili.",
    "%s shared »%s« with \"%s\"." : "%s jagas faili »%s« \"%s\"--ga.",
    "%s on %s" : "%s tiimis „%s“",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s jagas »%2$s« sinuga.\nPeaksid olema juba saanud eraldi meili lingiga sellele juurdepääsuks.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s jagas »%2$s« sinuga. Peaksid olema juba saanud eraldi meili lingiga sellele juurdepääsuks.",
    "Password to access »%1$s« shared to you by %2$s" : "„%1$s“ ligipääsu salasõna, mida jagas sulle %2$s ",
    "Password to access »%s«" : "Salasõna ligipääsuks: %s",
    "It is protected with the following password:" : "See on kaitstud järgneva salasõnaga:",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "Click the button below to open it." : "Avamiseks vajuta allolevat nuppu.",
    "Open »%s«" : "Ava „%s“",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s jagas sinuga mitut faili.\nPeaksid olema juba saanud eraldi meili lingiga nendele juurdepääsuks.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s jagas sinuga mitut faili. Peaksid olema juba saanud eraldi meili lingiga nendele juurdepääsuks.",
    "Password to access files shared to you by %1$s" : "Salasõna ligipääsuks failidele, mida jagas sinuga %1$s",
    "Password to access files" : "Salasõna ligipääsuks failidele",
    "%s shared multiple files with \"%s\"." : "%s jagas mitu faili „%s“ tiimiga.",
    "%s shared multiple files with you." : "%s jagas sinuga mitut faili.",
    "Boot up" : "Käivitamisel",
    "Nextcloud Initialization" : "Nextcloudi valmendamine",
    "Circles App Initialization" : "Tiimide rakenduse valmendamine",
    "Fresh installation status" : "Uue paigalduse olek",
    "Building Local Database" : "Loon kohalikku andmebaasi",
    "Adding local users and moderators" : "Lisan kohalikke kasutajaid ja moderaatoreid",
    "Show all teams" : "Näita kõiki tiime",
    "Create a new team" : "Loo uus tiim",
    "Files" : "Failid",
    "The team is not federated" : "See tiim ei osale liitpilves",
    "You cannot join this team" : "Sa ei saa selle tiimiga liituda",
    "This member is not a moderator" : "See liige pole moderaator",
    "Insufficient privileges" : "Pole piisavalt õigusi",
    "This member does not exist" : "Seda liiget pole olemas",
    "This member is the owner of the team" : "See liige on ka tiimi omanik",
    "Level cannot be changed for this type of member" : "Sellist tüüpi liikme taset ei saa muuta",
    "%s (Team owned by %s)" : "%s (tiimi  omanik on %s)",
    "You are now a member of the Team \"%2$s\"" : "Sa oled nüüd „%2$s“ tiimi liige",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s kutsus sind „%2$s“ tiimi",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s saatis kutse liitumaks „%2$s“ tiimiga",
    "Accept" : "Nõustu",
    "Refuse" : "Keeldu",
    "Leave the team" : "Lahku tiimist",
    "%s" : "%s",
    "Personal team" : "Isiklik tiim",
    "%s owned by %s" : "%s, mille omanik on %s",
    "You have no permission to create a new team" : "Sul pole õigusi uue tiimi loomiseks",
    "%s shared a file with \"%s\"." : "%s jagas faili „%s“ tiimiga.",
    "%s shared a file with you." : "%s jagas faili sinuga.",
    "%1$s shared %2$s with %3$s" : "%1$s jagas „%3$s“ tiimiga: %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s jagas „%3$s“ tiimiga: %2$s",
    "Open %s" : "Ava %s ",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s jagas sinuga sisu.\nSa peaksid nüüd olema saanud e-kirja ligipääsuks vajaliku lingiga.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s jagas sinuga sisu. Sa peaksid nüüd olema saanud e-kirja ligipääsuks vajaliku lingiga.",
    "Password to access content shared with you by %1$s" : "Salasõna ligipääsuks sisule, mida jagas sulle %1$s",
    "Password to access content" : "Salasõna ligipääsuks sisule",
    "This item is already shared with this team" : "See objekt on  juba selle tiimiga jagatud",
    "Bring cloud-users closer together." : "Liida pilvekasutajaid tihedamalt kokku.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Tiimide rakendus võimaldab kasutajatel luua kasutajatest, kolleegidest ja sõpradest omi gruppe\nNing neid gruppe saavad kõik muud rakendused kasutada sisu jagamisel.",
    "Failed to load teams" : "Tiimide laadimine ei õnnestunud",
    "Try again" : "Proovi uuesti",
    "No teams found" : "Tiime ei leidu",
    "Join or create teams to see them here." : "Nägemaks siin tiime, koosta oma tiim või liitu mõnega.",
    "Create your first team" : "Koosta oma esimene tiim!",
    "Loading…" : "Andmed on laadimisel…",
    "More teams" : "Veel tiime",
    "No files in here" : "Siin ei ole faile",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "Shared to Circles" : "Jagatud tiimidega",
    "Testing Basic Circle Creation" : "Testin lihtsa tiimi loomist",
    "This feature is not available for personal circles" : "See funktsionaalus pole saadaval isiklike tiimide jaoks",
    "You are already a member of this circle" : "Sa juba oled selle tiimi liige",
    "You have been blocked from this circle" : "Sul on keeld selle tiimiga liitumiseks",
    "The account is already a member of this circle" : "See kasutajakonto juba on selle tiimi liige",
    "The account has already been invited into this circle" : "See kasutajakonto juba on saanud kutse siia tiimi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.0p0.tgz: nextcloud/apps/circles/l10n/et_EE.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Tiimid",
    "You created the team {circle}" : "Lõid tiimi {circle}",
    "{author} created the team {circle}" : "{author} lõi tiimi {circle} ",
    "You deleted {circle}" : "Kustutasid {circle}",
    "{author} deleted {circle}" : "{author} kustutas {circle}",
    "You made {member} join {circle}" : "Panid {member} {circle}-ga liituma",
    "{author} made {member} join {circle}" : "{author} pani {member} {circle}-ga liituma",
    "You added team {member} as member to {circle}" : "Lisasid tiimiliikme {member}{circle} liikmeks",
    "{author} added team {member} as member to {circle}" : "{author}lisas tiimiliikme {member} {circle} liikmeks",
    "You made {member} leave {circle}" : "Panid {member} {circle}-st lahkuma",
    "{author} made {member} leave {circle}" : "{author} pani {member} {circle}-st lahkuma",
    "You removed {member} from {circle}" : "Eemaldasid {member} {circle}-st",
    "{author} removed {member} from {circle}" : "{author} eemaldas {member} {circle}-st",
    "You joined {circle}" : "Liitusid {circle}-ga",
    "{member} joined {circle}" : "{member} liitus {circle}-ga",
    "You accepted the invitation to join {circle}" : "Võtsid vastu kutse {circle}-ga liitumiseks ",
    "{member} accepted the invitation to join {circle}" : "{member} võttis vastu kutse {circle}-ga liitumiseks",
    "You added {member} as member to {circle}" : "Lisasid {member} {circle} liikmeks",
    "You have been added as member to {circle} by {author}" : "Sind lisati {circle} liikmeks {author} poolt",
    "{member} has been added as member to {circle} by {author}" : "{member} lisati {circle} liikmeks {author} poolt",
    "You added {external} to {circle}" : "Lisasid {external} {circle}-sse",
    "{external} has been added to {circle} by {author}" : "{external} lisati {circle}-sse {author} poolt",
    "You accepted {member}'s request to join {circle}" : "Aksepteerisid {member} soovi liituda {circle}-ga",
    "Your request to join {circle} has been accepted by {author}" : "Sinu liitumissoov {circle}-ga liitumiseks on {author} poolt heaks kiidetud",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} liitumissoov {circle}-ga liitumiseks on {author} poolt heaks kiidetud",
    "You left {circle}" : "Lahkusid {circle}-st",
    "{member} left {circle}" : "{member} lahkus {circle}-st",
    "You declined the invitation to join {circle}" : "Keeldusid kutsest „{circle}“ tiimiga liitumiseks",
    "{member} declined an invitation to join {circle}" : "{member} keeldus kutsest {circle}-ga liitumiseks",
    "You cancelled your request to join {circle}" : "Tühistasid liitumissoovi „{circle}“ tiimiga",
    "{member} cancelled a request to join {circle}" : "{member} tühistas {circle}-ga liitumise soovi",
    "You have been removed from {circle} by {author}" : "Sind eemaldati {circle}-st {author} poolt",
    "{member} has been removed from {circle} by {author}" : "{member} eemaldati {circle}-st {author} poolt",
    "You removed {external} from {circle}" : "Eemaldasid {external} {circle}-st",
    "{external} has been removed from {circle} by {author}" : "{external} eemaldati {circle}-st {author} poolt",
    "You cancelled {member}'s invitation to join {circle}" : "Tühistasid {member} kutse {circle}-ga liitumiseks",
    "Your invitation to join {circle} has been cancelled by {author}" : "Sinu kutse {circle}-ga liitumiseks tühistati {author} poolt",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} tühistas {member} kutse {circle}-ga liitumiseks",
    "You dismissed {member}'s request to join {circle}" : "Keeldusid {member} soovist liituda {circle}-ga",
    "Your request to join {circle} has been dismissed by {author}" : "Su {circle}-ga liitumise soov lükati tagasi {author} poolt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} soov liituda {circle}-ga lükati {author} poolt tagasi",
    "You invited {member} to join {circle}" : "Kutsusid {member} {circle}-ga liituma",
    "You have been invited to join {circle} by {author}" : "Sind kutsuti {circle}-ga liituma {author} poolt",
    "{member} has been invited to join {circle} by {author}" : "{member} kutsuti {circle}-ga liituma {author} poolt",
    "You changed {member}'s level in {circle} to %1$s" : "Muutsid {member} taseme {circle}-s %1$s-le",
    "{author} changed your level in {circle} to %1$s" : "{author} muutis sinu taset {circle}-s %1$s-le",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} muutis {member} taset {circle}-s %1$s-le",
    "You sent a request to join {circle}" : "Saatsid soovi {circle}-ga liituda",
    "{member} sent a request to join {circle}" : "{member} saatis soovi liituda {circle}-ga",
    "You are the new owner of {circle}" : "Oled {circle} uus omanik",
    "{member} is the new owner of {circle}" : "{member} on {circle} uus omanik",
    "On events happening in a <strong>team</strong> of which you are a member" : "Sündmuste kohta, mis toimuvad <strong>tiimis</strong>, mille liige te olete",
    "Any important event in a <strong>team</strong> you are moderating" : "Iga oluline sündmus <strong>tiimis</strong>, mida modereerite",
    "On global events happening in any <strong>team</strong>" : "Mis tahes <strong>tiimis</strong> toimuvate globaalsete sündmuste kohta",
    "Single" : "Üks",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Visible" : "Nähtav",
    "Open" : "Ava",
    "Invite" : "Kutse",
    "Join request" : "Liitumissoov",
    "Friends" : "Sõbrad",
    "Password protected" : "Kaitstud salasõnaga",
    "No Owner" : "Omanikuta",
    "Hidden" : "Peidetud",
    "Backend" : "Taustateenus",
    "Local" : "Kohalik",
    "Root" : "Juur",
    "Team invite" : "Tiimi kutse",
    "Federated" : "Liitpilves",
    "Mount point" : "Kinnituskoht",
    "Nextcloud Account" : "Nextcloudi kasutajakonto",
    "Nextcloud Group" : "Nextcloudi Grupp",
    "Email address" : "E-posti aadress",
    "Contact" : "Kontakt",
    "Team" : "Tiim",
    "Nextcloud App" : "Nextcloudi rakendus",
    "Teams App" : "Tiimide rakendus",
    "Admin Command Line" : "Haldus käsurealt",
    "Member" : "Liige",
    "Moderator" : "Moderaator",
    "Admin" : "Admin",
    "Owner" : "Omanik",
    "%s shared »%s« with you." : "%s jagas sinuga „%s“ faili.",
    "%s shared »%s« with \"%s\"." : "%s jagas faili »%s« \"%s\"--ga.",
    "%s on %s" : "%s tiimis „%s“",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s jagas »%2$s« sinuga.\nPeaksid olema juba saanud eraldi meili lingiga sellele juurdepääsuks.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s jagas »%2$s« sinuga. Peaksid olema juba saanud eraldi meili lingiga sellele juurdepääsuks.",
    "Password to access »%1$s« shared to you by %2$s" : "„%1$s“ ligipääsu salasõna, mida jagas sulle %2$s ",
    "Password to access »%s«" : "Salasõna ligipääsuks: %s",
    "It is protected with the following password:" : "See on kaitstud järgneva salasõnaga:",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "Click the button below to open it." : "Avamiseks vajuta allolevat nuppu.",
    "Open »%s«" : "Ava „%s“",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s jagas sinuga mitut faili.\nPeaksid olema juba saanud eraldi meili lingiga nendele juurdepääsuks.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s jagas sinuga mitut faili. Peaksid olema juba saanud eraldi meili lingiga nendele juurdepääsuks.",
    "Password to access files shared to you by %1$s" : "Salasõna ligipääsuks failidele, mida jagas sinuga %1$s",
    "Password to access files" : "Salasõna ligipääsuks failidele",
    "%s shared multiple files with \"%s\"." : "%s jagas mitu faili „%s“ tiimiga.",
    "%s shared multiple files with you." : "%s jagas sinuga mitut faili.",
    "Boot up" : "Käivitamisel",
    "Nextcloud Initialization" : "Nextcloudi valmendamine",
    "Circles App Initialization" : "Tiimide rakenduse valmendamine",
    "Fresh installation status" : "Uue paigalduse olek",
    "Building Local Database" : "Loon kohalikku andmebaasi",
    "Testing Basic Circle Creation" : "Testin lihtsa tiimi loomist",
    "Adding local users and moderators" : "Lisan kohalikke kasutajaid ja moderaatoreid",
    "Show all teams" : "Näita kõiki tiime",
    "Create a new team" : "Loo uus tiim",
    "Files" : "Failid",
    "This feature is not available for personal circles" : "See funktsionaalus pole saadaval isiklike tiimide jaoks",
    "The team is not federated" : "See tiim ei osale liitpilves",
    "You cannot join this team" : "Sa ei saa selle tiimiga liituda",
    "This member is not a moderator" : "See liige pole moderaator",
    "Insufficient privileges" : "Pole piisavalt õigusi",
    "This member does not exist" : "Seda liiget pole olemas",
    "This member is the owner of the team" : "See liige on ka tiimi omanik",
    "Level cannot be changed for this type of member" : "Sellist tüüpi liikme taset ei saa muuta",
    "You are already a member of this circle" : "Sa juba oled selle tiimi liige",
    "You have been blocked from this circle" : "Sul on keeld selle tiimiga liitumiseks",
    "The account is already a member of this circle" : "See kasutajakonto juba on selle tiimi liige",
    "The account has already been invited into this circle" : "See kasutajakonto juba on saanud kutse siia tiimi",
    "%s (Team owned by %s)" : "%s (tiimi  omanik on %s)",
    "You are now a member of the Team \"%2$s\"" : "Sa oled nüüd „%2$s“ tiimi liige",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s kutsus sind „%2$s“ tiimi",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s saatis kutse liitumaks „%2$s“ tiimiga",
    "Accept" : "Nõustu",
    "Refuse" : "Keeldu",
    "Leave the team" : "Lahku tiimist",
    "%s" : "%s",
    "Personal team" : "Isiklik tiim",
    "%s owned by %s" : "%s, mille omanik on %s",
    "You have no permission to create a new team" : "Sul pole õigusi uue tiimi loomiseks",
    "%s shared a file with \"%s\"." : "%s jagas faili „%s“ tiimiga.",
    "%s shared a file with you." : "%s jagas faili sinuga.",
    "%1$s shared %2$s with %3$s" : "%1$s jagas „%3$s“ tiimiga: %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s jagas „%3$s“ tiimiga: %2$s",
    "Open %s" : "Ava %s ",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s jagas sinuga sisu.\nSa peaksid nüüd olema saanud e-kirja ligipääsuks vajaliku lingiga.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s jagas sinuga sisu. Sa peaksid nüüd olema saanud e-kirja ligipääsuks vajaliku lingiga.",
    "Password to access content shared with you by %1$s" : "Salasõna ligipääsuks sisule, mida jagas sulle %1$s",
    "Password to access content" : "Salasõna ligipääsuks sisule",
    "This item is already shared with this team" : "See objekt on  juba selle tiimiga jagatud",
    "Bring cloud-users closer together." : "Liida pilvekasutajaid tihedamalt kokku.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Tiimide rakendus võimaldab kasutajatel luua kasutajatest, kolleegidest ja sõpradest omi gruppe\nNing neid gruppe saavad kõik muud rakendused kasutada sisu jagamisel.",
    "Failed to load teams" : "Tiimide laadimine ei õnnestunud",
    "Try again" : "Proovi uuesti",
    "No teams found" : "Tiime ei leidu",
    "Join or create teams to see them here." : "Nägemaks siin tiime, koosta oma tiim või liitu mõnega.",
    "Create your first team" : "Koosta oma esimene tiim!",
    "Loading…" : "Andmed on laadimisel…",
    "More teams" : "Veel tiime",
    "No files in here" : "Siin ei ole faile",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "Teams' files" : "Tiimi failid",
    "Select team to filter by" : "Vali tiim, mille alusel soovid filtreerida",
    "Please select teams to filter by" : "Palun vali tiimid, mille järgi filtreerida",
    "No files found for the selected teams" : "Valitud tiimide jaoks ei leidu ühtegi faili",
    "Shared to Circles" : "Jagatud tiimidega",
    "Circle" : "Tiimid"
},
"nplurals=2; plural=(n != 1);");
